/*
 * Copyright 2012-2013 Ray Holder
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.rholder.moar.concurrent.thread;

import java.util.concurrent.ThreadFactory;

/**
 * Assumes a group up front. All threads created via this factory will be under
 * that group. Conceived of because common builders do not provide a group
 * option.
 *
 * @author Jason Dunkelberger (dirkraft)
 */
public class GroupThreadFactory implements ThreadFactory {

    private final ThreadGroup threadGroup;

    public GroupThreadFactory(ThreadGroup threadGroup) {
        this.threadGroup = threadGroup;
    }

    @Override
    public Thread newThread(Runnable r) {
        return new Thread(threadGroup, r);
    }
}